import AbstractTokenGenerator from './AbstractTokenGenerator';
import { Token, TokenResponse } from './types';
declare type AuthorizationCodeFlowTokenGeneratorConfig = {
    clientId: string;
    clientSecret: string;
    path: string;
    scheme: string;
    redirectUri: string;
    port?: string;
    scope?: string;
};
declare type GenerateTokenParameters = {
    code: string;
    state?: string;
};
interface AuthorizationCodeToken extends Token {
    access_token: string;
    token_type: string;
    refresh_token: string;
    expires_in?: number;
    scope?: string;
}
declare type AuthorizationCodeFlowResponse = TokenResponse<AuthorizationCodeToken>;
/**
 * This generator take cares of the second part of the authorization code flow : the part where you have a "code"
 * and you have validated the "state"
 * @See {@link https://oauth2.thephpleague.com/authorization-server/auth-code-grant/|the great article of the PHP League} about authorization code flow.
 */
declare class AuthorizationCodeFlowTokenGenerator extends AbstractTokenGenerator<AuthorizationCodeToken, AuthorizationCodeFlowTokenGeneratorConfig> {
    /**
     * This function needs no generate an access token
     */
    generateToken(parameters: GenerateTokenParameters): Promise<AuthorizationCodeFlowResponse>;
    /**
     * This function needs to refresh the current possibly expired access token
     * and return a Promise that will be resolved with a fresh access token
     */
    refreshToken(oldAccessToken: null | AuthorizationCodeToken): Promise<AuthorizationCodeFlowResponse>;
    checkTokenGeneratorConfig(config: AuthorizationCodeFlowTokenGeneratorConfig): void;
    private _checkGenerateParameters;
}
export default AuthorizationCodeFlowTokenGenerator;
